@@ -119,12 +119,12 @@ class ChatCompletionsRequest(AbstractModel):
 当选择流式输出审核时，可能会出现部分内容已输出，但中间某一段响应中的 FinishReason 值为 sensitive，此时说明安全审核未通过。如果业务场景有实时文字上屏的需求，需要自行撤回已上屏的内容，并建议自定义替换为一条提示语，如 “这个问题我不方便回答，不如我们换个话题试试”，以保障终端体验。
         :type StreamModeration: bool
         :param _TopP: 说明：
-1. 影响输出文本的多样性，取值区间为 [0.0, 1.0]。取值越大，生成文本的多样性越强。
-2. 模型已有默认参数，不传值时使用各模型推荐值，不推荐用户修改。
+1. 影响输出文本的多样性。模型已有默认参数，不传值时使用各模型推荐值，不推荐用户修改。
+2. 取值区间为 [0.0, 1.0]。取值越大，生成文本的多样性越强。
         :type TopP: float
         :param _Temperature: 说明：
-1. 影响模型输出多样性，取值区间为 [0.0, 2.0]。较高的数值会使输出更加多样化和不可预测，而较低的数值会使其更加集中和确定。
-2. 模型已有默认参数，不传值时使用各模型推荐值，不推荐用户修改。
+1. 影响模型输出多样性，模型已有默认参数，不传值时使用各模型推荐值，不推荐用户修改。
+2. 取值区间为 [0.0, 2.0]。较高的数值会使输出更加多样化和不可预测，而较低的数值会使其更加集中和确定。
         :type Temperature: float
         :param _EnableEnhancement: 功能增强（如搜索）开关。
 说明：
@@ -151,6 +151,8 @@ class ChatCompletionsRequest(AbstractModel):
 2. false：开关关闭，true：开关打开。
 3. 未传值时默认开关关闭（false）。
         :type Citation: bool
+        :param _EnableSpeedSearch: 是否开启极速版搜索，默认false，不开启；在开启且命中搜索时，会启用极速版搜索，流式输出首字返回更快。
+        :type EnableSpeedSearch: bool
         """
         self._Model = None
         self._Messages = None
@@ -164,6 +166,7 @@ class ChatCompletionsRequest(AbstractModel):
         self._CustomTool = None
         self._SearchInfo = None
         self._Citation = None
+        self._EnableSpeedSearch = None
 
     @property
     def Model(self):
@@ -261,6 +264,14 @@ class ChatCompletionsRequest(AbstractModel):
     def Citation(self, Citation):
         self._Citation = Citation
 
+    @property
+    def EnableSpeedSearch(self):
+        return self._EnableSpeedSearch
+
+    @EnableSpeedSearch.setter
+    def EnableSpeedSearch(self, EnableSpeedSearch):
+        self._EnableSpeedSearch = EnableSpeedSearch
+
 
     def _deserialize(self, params):
         self._Model = params.get("Model")
@@ -287,6 +298,7 @@ class ChatCompletionsRequest(AbstractModel):
             self._CustomTool._deserialize(params.get("CustomTool"))
         self._SearchInfo = params.get("SearchInfo")
         self._Citation = params.get("Citation")
+        self._EnableSpeedSearch = params.get("EnableSpeedSearch")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -439,8 +451,10 @@ class Choice(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _FinishReason: 结束标志位，可能为 stop 或 sensitive。
-stop 表示输出正常结束，sensitive 只在开启流式输出审核时会出现，表示安全审核未通过。
+        :param _FinishReason: 结束标志位，可能为 stop、 sensitive或者tool_calls。
+stop 表示输出正常结束。
+sensitive 只在开启流式输出审核时会出现，表示安全审核未通过。
+tool_calls 标识函数调用。
         :type FinishReason: str
         :param _Delta: 增量返回值，流式调用时使用该字段。
 注意：此字段可能返回 null，表示取不到有效值。
